Package: igvShiny
Title: igvShiny: a wrapper of Integrative Genomics Viewer (IGV - an
        interactive tool for visualization and exploration integrated
        genomic data)
Version: 1.9.43
Date: 2026-07-29
Authors@R: c(
    person("Paul","Shannon", role = c("aut"), 
    email = "paul.thurmond.shannon@gmail.com"),
    person("Arkadiusz", "Gladki", role=c("aut", "cre"), 
    email="gladki.arkadiusz@gmail.com", comment = c(ORCID = "0000-0002-7059-6378")),
    person("Karolina","Scigocka", role = c("aut"),
    email = "scigocka.karolina@gmail.com"),
    person("Carolina", "Heimann", role = c("ctb"),
    email = "carolina.heimann@gmail.com"),
    person("Steffen", "Klasberg", role = c("ctb"),
    email = "klasberg@dkms-lab.de"),
    person("Vincent", "Carey", role = c("ctb"),
    email = "stvjc@channing.harvard.edu"),
    person("Parv", "Sachdeva", role = c("ctb"),
    email = "parv.sachdeva@sonomabio.com"),
    person("Mateusz", "Gladki", role = c("ctb"),
    email = "gladkiimateusz@gmail.com"),
    person("R Consortium", role = "fnd")
    )
Description: This package is a wrapper of Integrative Genomics Viewer (IGV).
    It comprises an htmlwidget version of IGV. It can be used as a module 
    in Shiny apps. 
URL: https://github.com/gladkia/igvShiny,
        https://gladkia.github.io/igvShiny/
BugReports: https://github.com/gladkia/igvShiny/issues
Depends: R (>= 3.5.0), GenomicRanges, methods, shiny
Imports: BiocGenerics, checkmate, futile.logger, GenomeInfoDbData,
        htmlwidgets, httr, jsonlite, randomcoloR, utils
Suggests: BiocStyle, bslib, covr, GenomicAlignments, knitr, Rsamtools,
        rtracklayer, testthat, shinytest2, VariantAnnotation
biocViews: Software, ShinyApps, Sequencing, Coverage
License: MIT + file LICENSE
Encoding: UTF-8
Collate: 'constants.R' 'genomeSpec.R' 'GWASTrack.R' 'igvShiny.R'
        'packages.R' 'utils.R' 'zzz.R'
RoxygenNote: 7.3.3
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/igvShiny
git_branch: devel
git_last_commit: d5bca1f
git_last_commit_date: 2026-08-22
Repository: Bioconductor 3.24
Date/Publication: 2026-08-23
NeedsCompilation: no
Packaged: 2026-08-23 22:36:47 UTC; biocbuild
Author: Paul Shannon [aut],
  Arkadiusz Gladki [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7059-6378>),
  Karolina Scigocka [aut],
  Carolina Heimann [ctb],
  Steffen Klasberg [ctb],
  Vincent Carey [ctb],
  Parv Sachdeva [ctb],
  Mateusz Gladki [ctb],
  R Consortium [fnd]
Maintainer: Arkadiusz Gladki <gladki.arkadiusz@gmail.com>
