# Generated by roxygen2: do not edit by hand

export(GWASTrack)
export(getGenomicRegion)
export(get_basic_genomes)
export(get_cas_genomes)
export(get_css_genomes)
export(get_tracks_dir)
export(igvShiny)
export(igvShinyOutput)
export(loadBamTrackFromLocalData)
export(loadBamTrackFromURL)
export(loadBedGraphTrack)
export(loadBedGraphTrackFromURL)
export(loadBedTrack)
export(loadCramTrackFromURL)
export(loadGFF3TrackFromLocalData)
export(loadGFF3TrackFromURL)
export(loadGwasTrack)
export(loadSegTrack)
export(loadVcfTrack)
export(parseAndValidateGenomeSpec)
export(removeTracksByName)
export(removeUserAddedTracks)
export(renderIgvShiny)
export(showGenomicRegion)
exportClasses(GWASTrack)
exportMethods(display)
exportMethods(getUrl)
import(BiocGenerics)
import(GenomeInfoDbData)
import(GenomicRanges)
import(httr)
import(shiny)
importFrom(futile.logger,flog.debug)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(methods,is)
importFrom(methods,new)
importFrom(randomcoloR,distinctColorPalette)
importFrom(utils,write.table)
